@@ -1,9 +1,9 @@
-/*  $Header: /home/cvsroot/dvipdfmx/src/pdfcolor.c,v 1.14 2007/11/22 11:45:39 chofchof Exp $
+/*  
     
     This is dvipdfmx, an eXtended version of dvipdfm by Mark A. Wicks.
 
-    Copyright (C) 2002 by Jin-Hwan Cho and Shunsaku Hirata,
-    the dvipdfmx project team <dvipdfmx@project.ktug.or.kr>
+    Copyright (C) 2002-2012 by Jin-Hwan Cho and Shunsaku Hirata,
+    the dvipdfmx project team.
     
     Copyright (C) 1998, 1999 by Mark A. Wicks <mwicks@kettering.edu>
 
@@ -1452,6 +1452,7 @@ pdf_get_colorspace_reference (int cspc_id)
   return pdf_link_obj(colorspace->reference);
 }
 
+#if 0
 int
 pdf_get_colorspace_num_components (int cspc_id)
 {
@@ -1496,6 +1497,7 @@ pdf_get_colorspace_subtype (int cspc_id)
 
   return colorspace->subtype;
 }
+#endif /* 0 */
 
 void
 pdf_init_colors (void)
